@@ -19,7 +19,7 @@ class BaseCredentialMixin(object):
     def get_user_info(self, request):
         if 'token' in request.GET and "platform_id" in request.GET:
             token = unquote(request.GET["token"])
-        elif 'HTTP_AUTHORIZATION' not in request.META and "platform_id" in request.GET:
+        elif 'HTTP_AUTHORIZATION' in request.META and "platform_id" in request.GET:
             token = request.META["HTTP_AUTHORIZATION"]
         else:
             raise PermissionDenied({"status": "error", "message": "you don't have permission to access"})
@@ -45,9 +45,7 @@ class BaseCredentialMixin(object):
 class CredentialMixin(BaseCredentialMixin):
 
     check_credential = True
-    with_settings_model = False # add for support old versions
-    if hasattr(settings, 'CREDENTIAL_MODEL'):
-        with_settigns_model = True
+    with_smart_auth = True
     
     # method for dashboard app
     def get_check_dash_auth(self, request):
@@ -91,11 +89,12 @@ class CredentialMixin(BaseCredentialMixin):
         return credential
 
     def initial(self, request, *args, **kwargs):
-        user_info = self.get_user_info(request)
-        self.smart_user_id = user_info['id']
-        self.smart_username = user_info['username']
-        if self.with_settings_model and self.check_credential:
-            self.credential = self.get_credential(request)
+        if self.with_smart_auth:
+            user_info = self.get_user_info(request)
+            self.smart_user_id = user_info['id']
+            self.smart_username = user_info['username']
+            if hasattr(settings, 'CREDENTIAL_MODEL') and self.check_credential:
+                self.credential = self.get_credential(request)
         return super().initial(request, *args, **kwargs)
 
     def get_credential_model(self):
@@ -109,4 +108,4 @@ class CredentialMixin(BaseCredentialMixin):
 class SmartAdminRequiredMixin(BaseCredentialMixin):
     def initial(self, request, *args, **kwargs):
         self.get_check_admin(request)
-        return super().initial(request, *args, **kwargs)
\ No newline at end of file
+        return super().initial(request, *args, **kwargs)
