@@ -18,9 +18,24 @@ if settings.DASHBOARD_URL.endswith("/"):
 else:
     DASHBOARD_URL = settings.DASHBOARD_URL + "/"
 
-__all__ = ('chunk_of_generators', 'get_smart_token', 'delete_file', 'write_file', 'upload_to_s3', 'check_file_exist',
-           'get_file_link', 'chunk_by_items', 'delete_s3_file', 'chunk_by_parts', 'decode', 'encode',
-           'get_full_integrations', 'write_ram_file', 'upload_to_s3_from_ram', 'delete_invalid_integrations')
+__all__ = (
+    'chunk_of_generators',
+    'get_smart_token',
+    'delete_file',
+    'write_file',
+    'upload_to_s3',
+    'check_file_exist',
+    'get_file_link',
+    'chunk_by_items',
+    'delete_s3_file',
+    'chunk_by_parts',
+    'decode',
+    'encode',
+    'get_full_integrations',
+    'write_ram_file',
+    'upload_to_s3_from_ram',
+    'delete_invalid_integrations',
+)
 
 
 def chunk_of_generators(iterable: Union[Generator, Iterator], max_value: int = 10):
@@ -61,8 +76,13 @@ def delete_file(filename: str):
     os.remove(filename)
 
 
-def write_file(filename: str, data: Union[list, dict, Generator], fieldnames: Optional[List[str]] = None,
-               delimiter: str = '\t', extension: str = '.tsv') -> str:
+def write_file(
+    filename: str,
+    data: Union[list, dict, Generator],
+    fieldnames: Optional[List[str]] = None,
+    delimiter: str = '\t',
+    extension: str = '.tsv',
+) -> str:
     """
     :param filename: str (path to local file)
     :param data: any (serialized data)
@@ -97,14 +117,15 @@ def upload_to_s3(filename: str, folder: str = "stats/") -> dict:
         s3_filename = filename[5:]
     else:
         s3_filename = filename
-    s3.meta.client.upload_file(filename, BUCKET_NAME, f"{folder}{s3_filename}", ExtraArgs={'ACL': 'public-read'},
-                               Config=config)
+    s3.meta.client.upload_file(
+        filename,
+        BUCKET_NAME,
+        f"{folder}{s3_filename}",
+        ExtraArgs={'ACL': 'public-read'},
+        Config=config,
+    )
 
-    return {
-        "status": "success",
-        "s3_filename": s3_filename,
-        "s3_folder": folder
-    }
+    return {"status": "success", "s3_filename": s3_filename, "s3_folder": folder}
 
 
 def check_file_exist(filename: str, folder: str = "stats/") -> bool:
@@ -125,7 +146,12 @@ def check_file_exist(filename: str, folder: str = "stats/") -> bool:
         return False
 
 
-def get_file_link(filename: str, folder: str = 'stats/', bucket: str = BUCKET_NAME, suffix: str = '.tsv') -> str:
+def get_file_link(
+    filename: str,
+    folder: str = 'stats/',
+    bucket: str = BUCKET_NAME,
+    suffix: str = '.tsv',
+) -> str:
     """
     :param filename: str
     :param folder: str
@@ -139,7 +165,11 @@ def get_file_link(filename: str, folder: str = 'stats/', bucket: str = BUCKET_NA
     if suffix in filename:
         filename = f"{folder}{filename}" if folder not in filename else filename
     else:
-        filename = f"{folder}{filename}{suffix}" if folder not in filename else f"{filename}{suffix}"
+        filename = (
+            f"{folder}{filename}{suffix}"
+            if folder not in filename
+            else f"{filename}{suffix}"
+        )
     # content = client.head_object(Bucket=BUCKET_NAME, Key=filename)
     bucket_location = client.get_bucket_location(Bucket=bucket)
     filepath = f"https://s3-{bucket_location['LocationConstraint']}.amazonaws.com/{BUCKET_NAME}/{filename}"
@@ -150,7 +180,7 @@ def get_file_link(filename: str, folder: str = 'stats/', bucket: str = BUCKET_NA
 def chunk_by_items(items: list, step: int):
     """Yield successive n-sized chunks from l."""
     for i in range(0, len(items), step):
-        yield items[i: i + step]
+        yield items[i : i + step]
 
 
 def get_full_integrations(platform: str, service_code: str) -> list:
@@ -175,7 +205,9 @@ def get_full_integrations(platform: str, service_code: str) -> list:
     return results
 
 
-def check_entities_equal(db_entity: any, new_entity: any, exclude_fields: Union[list, tuple, None] = None) -> bool:
+def check_entities_equal(
+    db_entity: any, new_entity: any, exclude_fields: Union[list, tuple, None] = None
+) -> bool:
     """
     :param db_entity: any
     :param new_entity: any
@@ -184,8 +216,18 @@ def check_entities_equal(db_entity: any, new_entity: any, exclude_fields: Union[
     db_entity = db_entity.__dict__
     new_entity = new_entity.__dict__
     if not exclude_fields:
-        exclude_fields = ('_state', 'date_time', 'sc_date_time', 'funnel_stage_duration', 'id')
-    return all((field, new_entity[field]) in db_entity.items() for field in db_entity if field not in exclude_fields)
+        exclude_fields = (
+            '_state',
+            'date_time',
+            'sc_date_time',
+            'funnel_stage_duration',
+            'id',
+        )
+    return all(
+        (field, new_entity[field]) in db_entity.items()
+        for field in db_entity
+        if field not in exclude_fields
+    )
 
 
 def chunk_by_parts(seq: list, parts: int) -> list:
@@ -200,7 +242,7 @@ def chunk_by_parts(seq: list, parts: int) -> list:
     out = []
     last = 0.0
     while last < len(seq):
-        out.append(seq[int(last):int(last + avg)])
+        out.append(seq[int(last) : int(last + avg)])
         last += avg
     return out
 
@@ -230,7 +272,9 @@ class __Crypt(object):
 
     def encrypt(self, str_to_enc, str_key=settings.SECRET_KEY):
         try:
-            aes_obj = AES.new(hashlib.sha256(str_key.encode()).digest(), AES.MODE_CFB, self.salt)
+            aes_obj = AES.new(
+                hashlib.sha256(str_key.encode()).digest(), AES.MODE_CFB, self.salt
+            )
             hx_enc = aes_obj.encrypt(str_to_enc)
             mret = b64encode(hx_enc).decode(self.enc_dec_method)
             mret = mret.replace('/', '-_-')
@@ -238,15 +282,21 @@ class __Crypt(object):
         except ValueError as value_error:
             if value_error.args[0] == 'IV must be 16 bytes long':
                 raise ValueError('Encryption Error: SALT must be 16 characters long')
-            elif value_error.args[0] == 'AES key must be either 16, 24, or 32 bytes long':
-                raise ValueError('Encryption Error: Encryption key must be either 16, 24, or 32 characters long')
+            elif (
+                value_error.args[0] == 'AES key must be either 16, 24, or 32 bytes long'
+            ):
+                raise ValueError(
+                    'Encryption Error: Encryption key must be either 16, 24, or 32 characters long'
+                )
             else:
                 raise ValueError(value_error)
 
     def decrypt(self, enc_str, str_key=settings.SECRET_KEY):
         try:
             enc_str = enc_str.replace('-_-', '/')
-            aes_obj = AES.new(hashlib.sha256(str_key.encode()).digest(), AES.MODE_CFB, self.salt)
+            aes_obj = AES.new(
+                hashlib.sha256(str_key.encode()).digest(), AES.MODE_CFB, self.salt
+            )
             str_tmp = b64decode(enc_str.encode(self.enc_dec_method))
             str_dec = aes_obj.decrypt(str_tmp)
             mret = str_dec.decode(self.enc_dec_method)
@@ -254,8 +304,12 @@ class __Crypt(object):
         except ValueError as value_error:
             if value_error.args[0] == 'IV must be 16 bytes long':
                 raise ValueError('Decryption Error: SALT must be 16 characters long')
-            elif value_error.args[0] == 'AES key must be either 16, 24, or 32 bytes long':
-                raise ValueError('Decryption Error: Encryption key must be either 16, 24, or 32 characters long')
+            elif (
+                value_error.args[0] == 'AES key must be either 16, 24, or 32 bytes long'
+            ):
+                raise ValueError(
+                    'Decryption Error: Encryption key must be either 16, 24, or 32 characters long'
+                )
             else:
                 raise ValueError(value_error)
 
@@ -274,7 +328,9 @@ def decode(enc: str, secret: Optional[str] = None):
     return c.decrypt(enc, secret)
 
 
-def write_ram_file(f: StringIO, data: Generator, fieldnames: list, delimiter='\t') -> StringIO:
+def write_ram_file(
+    f: StringIO, data: Generator, fieldnames: list, delimiter='\t'
+) -> StringIO:
     writer = csv.DictWriter(f, delimiter=delimiter, fieldnames=fieldnames)
     writer.writeheader()
     for row in data:
@@ -282,8 +338,12 @@ def write_ram_file(f: StringIO, data: Generator, fieldnames: list, delimiter='\t
     return f
 
 
-def upload_to_s3_from_ram(content: Union[StringIO, BytesIO], filename: str, folder: str = 'yandex_files/',
-                          suffix: str = '.tsv'):
+def upload_to_s3_from_ram(
+    content: Union[StringIO, BytesIO],
+    filename: str,
+    folder: str = 'yandex_files/',
+    suffix: str = '.tsv',
+):
     if filename.startswith('/tmp/'):
         s3_filename = filename[5:]
     else:
@@ -291,22 +351,37 @@ def upload_to_s3_from_ram(content: Union[StringIO, BytesIO], filename: str, fold
     if suffix not in s3_filename:
         s3_filename = f"{s3_filename}{suffix}"
     s3 = boto3.resource('s3')
-    body = content.getvalue().encode('utf-8') if isinstance(content, StringIO) else content.getvalue()
-    s3.meta.client.put_object(Bucket=BUCKET_NAME, Key=f'{folder}{s3_filename}',
-                              Body=body, ACL='public-read')
-    return {
-        "status": "success",
-        "s3_filename": s3_filename,
-        "s3_folder": folder
-    }
+    body = (
+        content.getvalue().encode('utf-8')
+        if isinstance(content, StringIO)
+        else content.getvalue()
+    )
+    s3.meta.client.put_object(
+        Bucket=BUCKET_NAME, Key=f'{folder}{s3_filename}', Body=body, ACL='public-read'
+    )
+    return {"status": "success", "s3_filename": s3_filename, "s3_folder": folder}
 
 
-def delete_invalid_integrations(integrations: list, models: Union[tuple, list],
-                                filter_query: Optional[dict] = None) -> list:
+def delete_invalid_integrations(
+    integrations: list, models: Union[tuple, list], filter_query: Optional[dict] = None
+) -> list:
     integration_ids = [i['integration_id'] for i in integrations]
     return [
-        model.objects.exclude(integration_id__in=integration_ids).delete() if not filter_query else
-        model.objects.filter(**filter_query
-                             ).exclude(integration_id__in=integration_ids).delete()
+        model.objects.exclude(integration_id__in=integration_ids).delete()
+        if not filter_query
+        else model.objects.filter(**filter_query)
+        .exclude(integration_id__in=integration_ids)
+        .delete()
         for model in models
     ]
+
+
+def decrypt_data(data: dict, token: str, salt: Optional[str] = None) -> dict:
+    if not salt:
+        salt = settings.EXECUTE_TOKEN
+    try:
+        execute_token = f'{token}:{salt}'
+        data = decode(data, execute_token)
+        return json.loads(data)
+    except:
+        raise ValueError('invalid secure params')
